@@ -38,7 +38,7 @@ class InfiniteTimeSeries:
         self._data.set_index("timestamp", inplace=True)
         self._data.index = pd.to_datetime(self._data.index)
         self._data = self._data.asfreq(frequency, method="ffill")
-        self._data = self._data.resample(frequency).interpolate(method='spline', order=3)
+        self._data = self._data.resample(frequency).interpolate(method='linear', order=3)
         self._data = self._data.iloc[0:min(self._get_intervals_per_year(frequency), len(self._data))]
         self._data.index = self._index_to_interval_of_year(self._data.index, frequency)
         self._noise_factor = noise_factor
@@ -78,10 +78,9 @@ class InfiniteTimeSeries:
             return cls(pd.read_csv(path), frequency, noise_factor, Path(path).stem)
 
     def _get_noise(self) -> float:
-        values_mean = self._data.mean()
-        values_std = self._data.std()
-        noise_mean = self._noise_factor * values_mean
-        return np.random.normal(noise_mean, values_std**2)
+        values_std = self._data.std() * self._noise_factor
+        noise = np.random.normal(0.0, values_std)
+        return noise
 
     def __getitem__(self, index):
         return self._data.iloc[index % len(self._data)] + self._get_noise()
